Method: Coinbase::FaucetTransaction#transaction_link

Defined in:
lib/coinbase/faucet_transaction.rb

Returns the link to the transaction on the blockchain explorer.

Returns:

  • (String)

    The link to the transaction on the blockchain explorer



35
36
37
# File 'lib/coinbase/faucet_transaction.rb', line 35

def transaction_link
  transaction.transaction_link
end