Method: Coinbase::Wallet#unstake
- Defined in:
- lib/coinbase/wallet.rb
#unstake ⇒ Coinbase::StakingOperation
Unstakes the given amount of the given Asset on the default address.
|
|
# File 'lib/coinbase/wallet.rb', line 180
|
Unstakes the given amount of the given Asset on the default address.
|
|
# File 'lib/coinbase/wallet.rb', line 180
|